package com.aucma.dms.service;

import com.aucma.dms.domain.DmsPlanMaintDetail;

import java.util.List;

/**
 * 保养计划明细Service接口
 *
 * @author xins
 * @date 2024-01-10
 */
public interface IDmsPlanMaintDetailService
{
    /**
     * 查询保养计划明细
     *
     * @param planMaintDetailId 保养计划明细主键
     * @return 保养计划明细
     */
    public DmsPlanMaintDetail selectDmsPlanMaintDetailByPlanMaintDetailId(Long planMaintDetailId);

    /**
     * 查询保养计划明细列表
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 保养计划明细集合
     */
    public List<DmsPlanMaintDetail> selectDmsPlanMaintDetailList(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 新增保养计划明细
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 结果
     */
    public int insertDmsPlanMaintDetail(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 修改保养计划明细
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 结果
     */
    public int updateDmsPlanMaintDetail(DmsPlanMaintDetail dmsPlanMaintDetail);

    /**
     * 批量删除保养计划明细
     *
     * @param planMaintDetailIds 需要删除的保养计划明细主键集合
     * @return 结果
     */
    public int deleteDmsPlanMaintDetailByPlanMaintDetailIds(Long[] planMaintDetailIds);

    /**
     * 删除保养计划明细信息
     *
     * @param planMaintDetailId 保养计划明细主键
     * @return 结果
     */
    public int deleteDmsPlanMaintDetailByPlanMaintDetailId(Long planMaintDetailId);


    /**
     * 查询保养计划明细列表，Join station and standard
     *
     * @param dmsPlanMaintDetail 保养计划明细
     * @return 保养计划明细
     */
    public List<DmsPlanMaintDetail> selectDmsPlanMaintDetailJoinList(DmsPlanMaintDetail dmsPlanMaintDetail);

    List<DmsPlanMaintDetail> selectDmsPlanMaintDetailListByPlanMaintId(Long planMaintId);

}
