package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsPlanMaintDetail;
import com.aucma.dms.service.IDmsPlanMaintDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 保养计划明细Controller
 *
 * @author xins
 * @date 2024-01-10
 */
@RestController
@RequestMapping("/dms/maintDetail")
public class DmsPlanMaintDetailController extends BaseController
{

    @Autowired
    private IDmsPlanMaintDetailService dmsPlanMaintDetailService;

    /**
     * 查询保养计划明细列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        startPage();
        List<DmsPlanMaintDetail> list = dmsPlanMaintDetailService.selectDmsPlanMaintDetailJoinList(dmsPlanMaintDetail);
        return getDataTable(list);
    }

    /**
     * 导出保养计划明细列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:export')" )
    ////@Log(title = "保养计划明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        List<DmsPlanMaintDetail> list = dmsPlanMaintDetailService.selectDmsPlanMaintDetailList(dmsPlanMaintDetail);
        ExcelUtil<DmsPlanMaintDetail> util = new ExcelUtil<DmsPlanMaintDetail>(DmsPlanMaintDetail.class);
        util.exportExcel(response, list, "保养计划明细数据");
    }

    /**
     * 获取保养计划明细详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:query')" )
    @GetMapping(value = "/{planMaintDetailId}")
    public AjaxResult getInfo(@PathVariable("planMaintDetailId") Long planMaintDetailId)
    {
        return success(dmsPlanMaintDetailService.selectDmsPlanMaintDetailByPlanMaintDetailId(planMaintDetailId));
    }
    /**
     * 根据计划id获取保养计划明细列表
     * */
    @GetMapping("/getDmsPlanMaintDetail/{planMaintId}")
    public TableDataInfo getDmsPlanMaintDetail(@PathVariable("planMaintId") Long planMaintId){
        List<DmsPlanMaintDetail> dmsPlanMaintDetails = dmsPlanMaintDetailService.selectDmsPlanMaintDetailListByPlanMaintId(planMaintId);
        return getDataTable(dmsPlanMaintDetails);
    }

    /**
     * 新增保养计划明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:add')" )
    ////@Log(title = "保养计划明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        return toAjax(dmsPlanMaintDetailService.insertDmsPlanMaintDetail(dmsPlanMaintDetail));
    }

    /**
     * 修改保养计划明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:edit')" )
    ////@Log(title = "保养计划明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsPlanMaintDetail dmsPlanMaintDetail)
    {
        return toAjax(dmsPlanMaintDetailService.updateDmsPlanMaintDetail(dmsPlanMaintDetail));
    }

    /**
     * 删除保养计划明细
     */
    //@PreAuthorize("@ss.hasPermi('dms:maintDetail:remove')" )
    ////@Log(title = "保养计划明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{planMaintDetailIds}")
    public AjaxResult remove(@PathVariable Long[] planMaintDetailIds)
    {
        return toAjax(dmsPlanMaintDetailService.deleteDmsPlanMaintDetailByPlanMaintDetailIds(planMaintDetailIds));
    }
}
